<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About MystiQ</source>
        <translation>о программе MystiQ</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Информация</translation>
    </message>
    <message>
        <source>Translators</source>
        <translation>Перевод</translation>
    </message>
    <message>
        <source>Portable</source>
        <translation>Портативная</translation>
    </message>
    <message>
        <source>Compiled with Qt %1</source>
        <translation>Скомпилирован с Qt %1</translation>
    </message>
    <message>
        <source>Compiled with libnotify %1</source>
        <translation>Компиляция осуществляется с помощью libnotify %1</translation>
    </message>
    <message>
        <source>MystiQ Homepage: %1</source>
        <translation>Страница проекта MystiQ: %1</translation>
    </message>
    <message>
        <source>Some audio-processing functionalities are provided by SoX.</source>
        <translation>Некоторые из функций обработки звука, предоставляются компанией SoX.</translation>
    </message>
    <message>
        <source>Spanish (Spain)</source>
        <extracomment>Spanish Language (Spain)</extracomment>
        <translation>Испанский (Испания)</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Лицензия</translation>
    </message>
    <message>
        <source>MystiQ is a GUI frontend for FFmpeg.</source>
        <translation>MystiQ графический интерфейс к FFmpeg.</translation>
    </message>
    <message>
        <source>Developers:&lt;br&gt; %1</source>
        <translation>Разработчики: &lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Swedish (Sweden)</source>
        <extracomment>Swedish Language (Sweden)</extracomment>
        <translation>Шведский (Швеция)</translation>
    </message>
    <message>
        <source>Japanese (Japan)</source>
        <extracomment>Japanese Language (Japan)</extracomment>
        <translation>Японский (Япония)</translation>
    </message>
    <message>
        <source>German (Germany)</source>
        <extracomment>German Language (Germany)</extracomment>
        <translation>Немецкий (Германия)</translation>
    </message>
    <message>
        <source>Italian (Italy)</source>
        <extracomment>Italian Language (Italy)</extracomment>
        <translation>Итальянский (Италия)</translation>
    </message>
    <message>
        <source>Application Name:&lt;br&gt; %1</source>
        <translation>Наименование приложения: &lt;br&gt; %1</translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License version 3.</source>
        <translation>Эта программа является свободным программным обеспечением; вы можете распространять и/или изменять ее в соответствии с условиями GNU General Public License version 3.</translation>
    </message>
    <message>
        <source>Turkish (Turkey)</source>
        <extracomment>Turkish Language (Turkey)</extracomment>
        <translation>Турецкий (Турция)</translation>
    </message>
    <message>
        <source>Many people have contributed translations. You can also help translate the MystiQ Video Converter into your own language. Visit </source>
        <translation>Многие люди внесли свой вклад в переводы. Вы также можете помочь перевести Mystiq Video Converter на ваш собственный язык. Заходите </translation>
    </message>
    <message>
        <source> and join a translation team.</source>
        <translation> присоединяйтесь к команде переводчиков.</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation>Изменения</translation>
    </message>
    <message>
        <source>Hungarian (Hungary)</source>
        <extracomment>Hungarian Language (Hungary)</extracomment>
        <translation>Венгерский (Венгрия)</translation>
    </message>
    <message>
        <source>Russian (Russia)</source>
        <extracomment>Russian Language (Russia)</extracomment>
        <translation>Русский (Россия)</translation>
    </message>
    <message>
        <source>Collaborators:&lt;br&gt; %1</source>
        <translation>Соавторы: &lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Some features of MystiQ Video Converter have been inspired by</source>
        <translation>Вдохновением для некоторых особенностей MystiQ видеоконвертера</translation>
    </message>
    <message>
        <source>Galician (Galicia)</source>
        <extracomment>Galician Language (Galicia)</extracomment>
        <translation>Галицкий (Галиция)</translation>
    </message>
    <message>
        <source>Icons Theme:&lt;br&gt; %1</source>
        <translation>Иконки Тема: &lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Indonesian (Indonesia)</source>
        <extracomment>Indonesian Language (Indonesia)</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutFFmpegDialog</name>
    <message>
        <source>About FFmpeg</source>
        <translation>О FFmpeg</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Available Codecs</source>
        <translation>Доступные Кодеки</translation>
    </message>
    <message>
        <source>FFmpeg is a complete, cross-platform solution to record, convert and stream audio and video. It includes libavcodec - the leading audio/video codec library.</source>
        <extracomment>ffmpeg description</extracomment>
        <translation>FFmpeg-это комплексное кроссплатформенное решение для записи, преобразования и потоковой передачи аудио и видео. Он включает в себя libavcodec-ведущую библиотеку аудио / видео кодеков.</translation>
    </message>
    <message>
        <source>FFmpeg is free software licensed under the LGPL or GPL.</source>
        <translation>Ffmpeg является свободным программным обеспечением под лицензией LGPL или GPL.</translation>
    </message>
    <message>
        <source>Please visit %1 for more information.</source>
        <translation>Пожалуйста, посетите %1 для получения дополнительной информации.</translation>
    </message>
</context>
<context>
    <name>AddTaskWizard</name>
    <message>
        <source>Add Tasks</source>
        <translation>Добавить задачу</translation>
    </message>
    <message>
        <source>Files to be converted</source>
        <translation>Файлы для изменения</translation>
    </message>
    <message>
        <source>Add files.</source>
        <translation>Добавить файлы.</translation>
    </message>
    <message>
        <source>Remove selected files.</source>
        <translation>Удалить выбранные файлы.</translation>
    </message>
    <message>
        <source>Output Settings</source>
        <translation>Настройки вывода результата</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Редактирование</translation>
    </message>
    <message>
        <source>Auto adjust output bitrate to reduce output file size.</source>
        <translation>Автоматическая настройка выходного битрейта для уменьшения размера итогового файла.</translation>
    </message>
    <message>
        <source>Auto Adjust Audio Bitrate</source>
        <translation>Автоматическая настройка аудио битрейта</translation>
    </message>
    <message>
        <source>Preset</source>
        <translation>Предустановка</translation>
    </message>
    <message>
        <source>Convert to</source>
        <translation>Преобразовать в</translation>
    </message>
    <message>
        <source>Output Path</source>
        <translation>Путь вывода</translation>
    </message>
    <message>
        <source>Select &amp;folder</source>
        <translation>Выбор и &amp;папка</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Браузер</translation>
    </message>
    <message>
        <source>Create &amp;new folder in source folder</source>
        <extracomment>Create a new folder (e.g. mystiq_output) in the folder containing the input files. Put the output files in the newly created folder.</extracomment>
        <translatorcomment>Создайте новую папку (например, mystiq_output) в папке, содержащей входные файлы. Поместите выходные файлы во вновь созданную папку.</translatorcomment>
        <translation>Создать &amp;новую папку в исходной папке</translation>
    </message>
    <message>
        <source>Folder Name</source>
        <translation>Имя папки</translation>
    </message>
    <message>
        <source>Output to &amp;source folder</source>
        <extracomment>put the output files in the same folder as the input files</extracomment>
        <translatorcomment>поместите выходные файлы в ту же папку, что и входные файлы</translatorcomment>
        <translation>Вывод к &amp;исходная папка</translation>
    </message>
    <message>
        <source>Please select at least one file.</source>
        <translation>Пожалуйста, выберите хотя бы один файл.</translation>
    </message>
    <message>
        <source>Select Files</source>
        <extracomment>This text is the title of an openfile dialog.</extracomment>
        <translation>Выбрать файлы</translation>
    </message>
    <message>
        <source>Multimedia</source>
        <translation>Мультимедиа</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Аудио</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Все файлы</translation>
    </message>
    <message>
        <source>Select Directory</source>
        <extracomment>This text is the title of an open directory dialog.</extracomment>
        <translation>Выбрать папку</translation>
    </message>
    <message>
        <source>Searching for files...</source>
        <translation>Поиск файлов...</translation>
    </message>
    <message>
        <source>Some files could not be found.</source>
        <translation>Некоторые файлы не удалось найти.</translation>
    </message>
    <message>
        <source>Folder does not exist. Create a new folder?</source>
        <translation>Папка не существует. Создать новую папку?</translation>
    </message>
    <message>
        <source>Failed to create folder. Please select another output folder.</source>
        <translation>Не удалось создать папку. Пожалуйста, выберите другую папку вывода.</translation>
    </message>
    <message>
        <source>Add Files</source>
        <translation>Добавить файлы</translation>
    </message>
    <message>
        <source>Remove Selected</source>
        <translation>Удалить выбранные</translation>
    </message>
    <message>
        <source>Clear List</source>
        <translation>Очистить список</translation>
    </message>
</context>
<context>
    <name>ConversionParameterDialog</name>
    <message>
        <source>Conversion Parameters</source>
        <translation>Параметры преобразования</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Аудио</translation>
    </message>
    <message>
        <source>Disable Audio</source>
        <translation>Отключить Аудио</translation>
    </message>
    <message>
        <source>Audio Options</source>
        <translation>Настройки Аудио</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation>Частота дискретизации</translation>
    </message>
    <message>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <source>Bitrate</source>
        <translation>Битрейт</translation>
    </message>
    <message>
        <source>(auto)</source>
        <translation>(авто)</translation>
    </message>
    <message>
        <source>kb/s</source>
        <translation>кб/с</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Каналы</translation>
    </message>
    <message>
        <source>Volume</source>
        <translation>Объем</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
    <message>
        <source>Disable Video</source>
        <translation>Отключить видео</translation>
    </message>
    <message>
        <source>Video Options</source>
        <translation>Настройки видео</translation>
    </message>
    <message>
        <source>Same Quantizer as Source</source>
        <translation>Тот же Квантователь, что и источник</translation>
    </message>
    <message>
        <source>Deinterlace</source>
        <translation>Деинтерлейсинг</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Ширина</translation>
    </message>
    <message>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Высота</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Кадрировать</translation>
    </message>
    <message>
        <source>Time</source>
        <extracomment>time-related options (speed, length)</extracomment>
        <translation>Время</translation>
    </message>
    <message>
        <source>Cutting</source>
        <extracomment>video time cutting: options for begin time and end time</extracomment>
        <translation>Разрезание</translation>
    </message>
    <message>
        <source>Cut</source>
        <comment>Cut video; select a range to convert</comment>
        <translation>Резать</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Предварительный просмотр</translation>
    </message>
    <message>
        <source>Scaling</source>
        <extracomment>time scaling, changing the speed of the output file</extracomment>
        <translation>Масштабирование</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Скорость</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Дополнительный</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Additional FFmpeg Options</source>
        <translation>Дополнительные опции FFmpeg</translation>
    </message>
    <message>
        <source>Copy Audio (Do not re-encode)</source>
        <translation>Копировать аудио (не перекодировать)</translation>
    </message>
    <message>
        <source>Insert Subtitle if Available</source>
        <translation>Вставить субтитры, если они имеются</translation>
    </message>
    <message>
        <source>Copy Video (Do not re-encode)</source>
        <translation>Копировать видео (не перекодировать)</translation>
    </message>
    <message>
        <source>qrc:/qml/main.qml</source>
        <translation>qrc:/qml/main.qml</translation>
    </message>
    <message>
        <source>Video Extra Options</source>
        <translation>Дополнительные опции Видео</translation>
    </message>
    <message>
        <source>Video to Black and White</source>
        <translation>Видео в черно-белом режиме</translation>
    </message>
    <message>
        <source>Vertical Flip</source>
        <translation>Вертикальный переворот</translation>
    </message>
    <message>
        <source>Horizontal Flip</source>
        <translation>Горизонтальный переворот</translation>
    </message>
    <message>
        <source>Rotate 90 degrees clockwise</source>
        <translation>Поворот на 90 градусов по часовой стрелке</translation>
    </message>
    <message>
        <source>Rotate 90 degrees counterclockwise</source>
        <translation>Поверните на 90 градусов против часовой стрелки</translation>
    </message>
    <message>
        <source>Rotate 180 degrees</source>
        <translation>Поворот на 180 градусов</translation>
    </message>
    <message>
        <source>3D Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Blue Gray Monochromatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Cyan Dubois</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green Magenta Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Cyan Half Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yellow Blue Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Cyan Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green Magenta Gray Monochromatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Green Gray Monochromatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConvertList</name>
    <message>
        <source>Cancel</source>
        <extracomment>Cancel the operation of adding new tasks</extracomment>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Adding files (%1/%2)</source>
        <extracomment>This text is the progress indicator of adding multiple tasks. %1 is the number of files that are already added. %2 is the total number of files.</extracomment>
        <translation>Добавление файлов (%1/%2)</translation>
    </message>
    <message>
        <source>Some files are not recognized by the converter.</source>
        <translation>Некоторые файлы не распознаются конвертером.</translation>
    </message>
    <message>
        <source>New File Name</source>
        <translation>Новое имя файла</translation>
    </message>
    <message>
        <source>Please input the new name for the output file.</source>
        <translation>Пожалуйста, введите новое имя для итогового файла.</translation>
    </message>
    <message>
        <source>Output Directory</source>
        <translation>Папка для сохранения</translation>
    </message>
    <message>
        <source>Error Message from FFmpeg:

</source>
        <translation>Сообщение об ошибке от FFmpeg:

</translation>
    </message>
    <message>
        <source>Drag and drop files here to add tasks.</source>
        <translation>Перетащите файлы сюда, чтобы добавить задачи.</translation>
    </message>
    <message>
        <source>Hide &quot;%1&quot;</source>
        <extracomment>Hide a column in the list. For example, the text maybe &apos;Hide &quot;Duration&quot;&apos;. The two &quot; are quotation marks in English, you may replace it with local quotation marks.</extracomment>
        <translation>Скрыть &quot; %1&quot;</translation>
    </message>
    <message>
        <source>Restore All Columns</source>
        <translation>Восстановить все столбцы</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Источник</translation>
    </message>
    <message>
        <source>Destination</source>
        <translation>Место назначения</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Продолжительность</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation>Размер файла</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <extracomment>Audio</extracomment>
        <translation>Частота дискретизации</translation>
    </message>
    <message>
        <source>Audio Bitrate</source>
        <translation>Аудио битрейт</translation>
    </message>
    <message>
        <source>Channels</source>
        <extracomment>Audio</extracomment>
        <translation>Каналы</translation>
    </message>
    <message>
        <source>Audio Codec</source>
        <translation>Аудио кодек</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Размер</translation>
    </message>
    <message>
        <source>Video Bitrate</source>
        <translation>Видео битрейт</translation>
    </message>
    <message>
        <source>Framerate</source>
        <extracomment>Video</extracomment>
        <translation>Частота кадров</translation>
    </message>
    <message>
        <source>Video Codec</source>
        <translation>Видео кодек</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Процесс</translation>
    </message>
    <message>
        <source>%1 Hz</source>
        <translation>%1 Гц</translation>
    </message>
    <message>
        <source>%1 kb/s</source>
        <translation>%1 кб/с</translation>
    </message>
    <message>
        <source>%1 fps</source>
        <translation>%1 частота кадров</translation>
    </message>
    <message>
        <source>Removing tasks...</source>
        <extracomment>Remove files from the tasklist</extracomment>
        <translation>Удаление задач...</translation>
    </message>
    <message>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <source>B</source>
        <extracomment>Bytes</extracomment>
        <translation>B</translation>
    </message>
    <message>
        <source>File Exists</source>
        <translation>Файл существует</translation>
    </message>
    <message>
        <source>%1 already exists on disk or in the task list. Still use this name as the output filename?</source>
        <translation>%1 уже существует на диске или в списке задач. По-прежнему использовать это имя в качестве итогового файла?</translation>
    </message>
    <message>
        <source>Remove Task</source>
        <translation>Удалить задачу</translation>
    </message>
    <message>
        <source>Cannot remove a task while it is in progress.</source>
        <translation>Не удается удалить задачу, пока она выполняется.</translation>
    </message>
    <message>
        <source>Finished</source>
        <extracomment>The text to be displayed on the progress bar when a conversion finishes</extracomment>
        <translation>Выполнено</translation>
    </message>
    <message>
        <source>Failed</source>
        <extracomment>The text to be displayed on the progress bar when a conversion fails</extracomment>
        <translation>Неудавшийся</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <extracomment>%1 is the error message</extracomment>
        <translation>Ошибка: %1</translation>
    </message>
</context>
<context>
    <name>ExtraTranslations</name>
    <message>
        <source>Convert between media file formats</source>
        <translation>Преобразование между форматами файлов мультимедиа</translation>
    </message>
    <message>
        <source>Media Converter</source>
        <translation>Медиаконвертор</translation>
    </message>
</context>
<context>
    <name>HelpMystiQDialog</name>
    <message>
        <source>User Manual</source>
        <translation>Руководство пользователя</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Fira Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:18pt; font-weight:600;&quot;&gt;MystiQ User&apos;s Manual&lt;/span&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/mystiq_96x96.png&quot; style=&quot;float: left;&quot; /&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter is a cross platform application. This application has as its sole objective the conversion of audio and video files to multiple formats. As a distinctive feature, MystiQ is an open source project, which means that the source code will always be available and everyone who wishes to contribute to the development is welcome.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter is free: you can redistribute it and / or modify it under the terms GNU (General Public License) published by the Free Software Foundation. MystiQ Video Converter is freely distributed with the sole purpose of being a useful application to your needs, but WITHOUT NO WARRANTY, even if its use is COMMERCIAL or MERELY A PARTICULAR PURPOSE See the GPL v3 license for more details. This application includes an English copy of the Software distribution license.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;The essential idea of ​​the development team is to provide a friendly and simple user interface. The simple is the essence of MystiQ, which means that it is not our objective to add features that complicate the operation of the application.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Currently MystiQ is mainly developed in C ++ taking advantage of the Qt5 graphic libraries. In the FFmpeg backend he is in charge of converting between formats, so we can say that MystiQ is simply a graphical interface for FFmpeg.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ currently allows you to convert to most existing video formats, as well as make it possible to extract audio and convert between audio formats. It also includes a small tool to trim videos based on the duration of these.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter currently supports the following audio and video formats:&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- Audio: mp3 m4a 3g2 ogg wav wma  ac3 ra ape flac opus&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- Video: avi vfw divx mpg mpeg m1v m2v mpv dv 3gp mov mp4 m4v mqv dat vcd ogg ogm ogv asf wmv bin iso vob mkv nsv ram flv rm swf ts rmvb dvr-ms m2t m2ts rec mts webm dv&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot1.png&quot; /&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Toolbar&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;In the upper part of the main window of the application we will find the toolbar with the following buttons:&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot2.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;ul style=&quot;margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;&quot;&gt;&lt;li style=&quot;&quot; style=&quot; margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Add Files:&lt;/span&gt; &lt;span style=&quot; font-size:12pt;&quot;&gt;Opens a dialog to select the video files you want to convert. Once selected, they are placed in the List of Conversion Tasks&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Start: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Start conversion process from the list of loaded items&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Stop: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Stops the process of converting an item&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Retry:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Retry the process of converting an item&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Retry All:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Retry the conversion process of all items in the list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Remove Selected:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove a selected item from the list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Remove Completed:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove all items from the list that have completed the conversion process&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Clear List:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove all items from the conversion list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Open Output Folder: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;From the system file manager open the folder that contains the converted files&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot; font-size:12pt;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Power Options:&lt;/span&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;  &lt;/span&gt;Choose whether to shut down, suspend or hibernate the computer when completing the conversion process of all items in the list&lt;/li&gt;&lt;/ul&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Audio Options&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot3.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Disable Audio:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to obtain a resulting file excluding sound.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Copy audio (do not recode):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to convert without processing the audio from the source file. The resulting file will have the same sound parameters as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Sample Rate:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; In audio production, a sample rate (or &amp;quot;sampling rate&amp;quot;) defines how many times per second a sound is sampled. Technically speaking, it is the frequency of samples used in a digital recording.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Bitrate:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; It&apos;s the bit rate or data that is processed per unit of time. The average bitrate for an MP3 file is 128 kbits per second or kbps.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Channels: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s the passage way a signal or data is transported. In case of audio files, it&apos;s the passage or communication channel in which a sound signal is transported from the player source to the speaker. An audio file can contain one, two or even more Channels.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Volume: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Allows you to configure the maximum volume of the destination file taking as a match the volume level of the source file.&lt;/span&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Video Options&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot4.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Insert Subtitle if Available: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;By checking this option, the application will verify if a subtitle file of the same name is found in the same location of the source file, if found, it will embed it in the resulting file. It is currently compatible with subtitles in SRT, SSA, ASS and SUB format.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Disable Video:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to obtain a resulting file excluding video.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- &lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Copy Video (Do not re-encode):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to convert without processing the video from the source file. The resulting file will have the same video parameters as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Video to Black and White: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It allows to obtain a video file is grayscale.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Flip and Rotate options: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;The resulting file will be rotated or flipped in the direction chosen.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- &lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Deinterlace: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s the process of converting interlaced video, such as common analog television signals or 1080i format HDTV signals, into a non-interlaced form. An interlaced video frame consists of two sub-fields taken in sequence, each sequentially scanned at odd, and then even, lines of the image sensor.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Same Quantizer as source: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s involved in image processing, is a lossy compression technique achieved by compressing a range of values to a single quantum value. Checking this option the resulting file will have the same deinterlacing as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Fira Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:18pt; font-weight:600;&quot;&gt;Руководство пользователя MystiQ&lt;/span&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/mystiq_96x96.png&quot; style=&quot;float: left;&quot; /&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter-это кроссплатформенное приложение. Это приложение имеет в качестве своей единственной цели преобразование аудио и видео файлов в другие форматы. Отличительной особенностью MystiQ является проект с открытым исходным кодом, что означает, что исходный код всегда будет доступен, и каждый, кто хочет внести свой вклад в разработку, будет приветствоваться.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter является бесплатным: вы можете распространять и / или изменять его на условиях GNU (General Public License), опубликованных Фондом свободного программного обеспечения. MystiQ Video Converter свободно распространяется с единственной целью быть полезным приложением для ваших нужд, но без каких-либо гарантий, даже если его использование является коммерческим или просто определенной целью смотрите лицензию GPL v3 для получения более подробной информации. Это приложение включает в себя английскую копию лицензии на распространение программного обеспечения.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Основная идея команды разработчиков состоит в том, чтобы обеспечить дружественный и простой пользовательский интерфейс. В простоте и заключается суть MystiQ, а это значит, что мы не ставим перед собой задачу добавлять функции, усложняющие работу приложения.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;В настоящее время MystiQ в основном разрабатывается на языке C ++ с использованием графических библиотек Qt5. В фоновом режиме FFmpeg он отвечает за конвертацию между форматами, поэтому мы можем сказать, что MystiQ-это просто графический интерфейс для FFmpeg.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;В настоящее время MystiQ позволяет конвертировать видео в большинство существующих форматов, а также позволяет извлекать аудио и конвертировать между аудиоформатами. Он также включает в себя небольшой инструмент для обрезки видео на основе их продолжительности.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter в настоящее время поддерживает следующие аудио и видео форматы:&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- Аудио: MP3 и M4A файлы 3g2 форматы OGG WAV и WMA с АС3 RA APE FLAC OPUS&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- Видео: AVI VFW DivX MPG MPEG m2v, m1v MPV DV 3GP MOV MP4 M4V MQV DAT VCD OGG OGM OGV ASF WMV BIN ISO VOB MKV NSV RAM FLV RM SWF TS RMVB DVR-MS m2t m2ts REC MTS WEBM DV&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot1.png&quot; /&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Панель инструментов&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;В верхней части главного окна приложения мы найдем панель инструментов со следующими кнопками:&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot2.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;ul style=&quot;margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;&quot;&gt;&lt;li style=&quot;&quot; style=&quot; margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Добавить файлы:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Открывает диалоговое окно для выбора видео файлов, которые вы хотите конвертировать. После выбора они помещаются в список задач конвертации&lt;/span&gt;&lt;/li&gt;&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/span&gt;Конвертация:&lt;span style=&quot; font-size:16pt;&quot;&gt;запуск процесса преобразования из списка загруженных элементов&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Стоп:&lt;/span&gt;&lt;/span&gt;останавливает процесс преобразования элемента.&lt;span style=&quot; font-size:12pt;&quot;&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Повтор:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;повторите процесс преобразования элемента.&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Повторить все:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;повторить процесс преобразования всех элементов в списке.&lt;span style=&quot; font-size:12pt;&quot;&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Удалить выбранный:&lt;span style=&quot; font-size:16pt;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;удалить выбранный элемент из списка.&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Удалить завершенные:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;удалить все элементы из списка, завершившие процесс преобразования.&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Очистить список:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;удалить все элементы из списка преобразования&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Открыть папку вывода:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;из системного файлового менеджера откройте папку, содержащую преобразованные файлы&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot; font-size:12pt;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Параметры питания:&lt;/span&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;&lt;/span&gt;выберите, следует ли выключить, приостановить или перевести компьютер в режим гибернации при завершении процесса преобразования всех элементов в списке.&lt;/li&gt;&lt;/ul&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Параметры Аудио&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot3.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Отключить звук:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;позволяет получить итоговый файл, без звука.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Копировать аудио (не перекодировать):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;позволяет конвертировать без обработки аудио из исходного файла. Итоговый файл будет иметь те же звуковые параметры, что и исходный файл.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Частота дискретизации:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;при производстве аудио частота дискретизации (или &quot;частота дискретизации&quot;) определяет, сколько раз в секунду производится выборка звука. Технически говоря, это частота сэмплов, используемых в цифровой записи.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Битрейт:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;это скорость передачи битов или данных, которые обрабатываются в единицу времени. Средний битрейт для MP3-файла составляет 128 Кбит / с или kbps.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Каналы:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;это способ прохождения сигнала или передачи данных. В случае аудиофайлов это проход или канал связи, по которому звуковой сигнал передается от источника плеера к динамику. Аудиофайл может содержать один, два или даже больше каналов.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Объём:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;позволяет настроить максимальный объем конечного файла, принимая за соответствие уровню объёма исходного файла.&lt;/span&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Опции Видео&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot4.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Вставить субтитр, если он доступен: установив этот флажок, приложение проверит, находится ли файл субтитров с тем же именем в том же месте исходного файла, если он будет найден, оно вставит его в результирующий файл. В настоящее время он совместим с субтитрами в формате SRT, SSA, ASS и SUB.&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Отключить видео:&lt;span style=&quot; font-size:16pt;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;позволяет получить итоговый файл, без видео.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;-&lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Копировать видео (не перекодировать):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;позволяет конвертировать без обработки видео из исходного файла. Итоговый файл будет иметь те же параметры видео, что и исходный файл.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Черно-белое видео:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;позволяет получить видеофайл в оттенках серого.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Опции переворачивания и поворота:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;итоговый файл будет повернут или перевернут в выбранном направлении.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;-&lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Деинтерлейс:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;это процесс преобразования чересстрочного видео, такого как обычные аналоговые телевизионные сигналы или сигналы HDTV формата 1080i, в не чересстрочную форму. Чересстрочный видеокадр состоит из двух последовательно взятых подполей, каждое из которых последовательно сканируется по нечетным, а затем четным линиям датчика изображения.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Тот же Квантователь, что и источник:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;он участвует в обработке изображений, представляет собой метод сжатия с потерями, достигаемый сжатием диапазона значений до одного квантового значения. При выборе этого параметра итоговый файл будет иметь тот же деинтерлейсинг, что и исходный файл.&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>InteractiveCuttingDialog</name>
    <message>
        <source>Cutting</source>
        <comment>Cutting as in &quot;cutting video&quot;</comment>
        <translation>Резка</translation>
    </message>
    <message>
        <source>Mark as Begin</source>
        <translation>Отметить как начало</translation>
    </message>
    <message>
        <source>Seek to Begin</source>
        <translation>Перемотка к началу</translation>
    </message>
    <message>
        <source>Play Selection</source>
        <translation>Выбор старта</translation>
    </message>
    <message>
        <source>Mark as End</source>
        <translation>Выбор окончания</translation>
    </message>
    <message>
        <source>Seek to End</source>
        <translation>Перемотка к концу</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Start conversion process.</source>
        <translation>Начать процесс конвертации.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файлы</translation>
    </message>
    <message>
        <source>&amp;Convert</source>
        <translation>&amp;Конвертация</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Редактирование</translation>
    </message>
    <message>
        <source>&amp;Add Files</source>
        <translation>&amp;Добавить файлы</translation>
    </message>
    <message>
        <source>Add files for conversion.</source>
        <translation>Добавить файлы и конвертировать.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Выхо&amp;д</translation>
    </message>
    <message>
        <source>Exit the program.</source>
        <translation>Выход из программы.</translation>
    </message>
    <message>
        <source>S&amp;top</source>
        <translation>О&amp;становить</translation>
    </message>
    <message>
        <source>Stop conversion process.</source>
        <translation>Остановка процесса конвертации.</translation>
    </message>
    <message>
        <source>Set &amp;Parameters</source>
        <translation>Установки &amp;Параметры</translation>
    </message>
    <message>
        <source>Set Parameters</source>
        <extracomment>Edit output file parameters.</extracomment>
        <translation>Установить параметры</translation>
    </message>
    <message>
        <source>Edit conversion parameters of selected files.</source>
        <translation>Редактирование параметров конвертирования выбранных файлов.</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>О &amp;Qt</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>О Qt</translation>
    </message>
    <message>
        <source>&amp;Open Output Folder</source>
        <translation>&amp;Открыть папку с результатом</translation>
    </message>
    <message>
        <source>Open output folder of the selected file.</source>
        <translation>Откройте итоговую папку  выбранного файла.</translation>
    </message>
    <message>
        <source>About &amp;FFmpeg</source>
        <translation>О &amp;FFmpeg</translation>
    </message>
    <message>
        <source>About FFmpeg</source>
        <translation>О FFmpeg</translation>
    </message>
    <message>
        <source>&amp;Remove Selected</source>
        <extracomment>remove selected (tasks, items)</extracomment>
        <translation>&amp;Удалить выбранные</translation>
    </message>
    <message>
        <source>Remove all selected items in the list.</source>
        <translation>Удалите все выбранные элементы из списка.</translation>
    </message>
    <message>
        <source>R&amp;emove Completed</source>
        <extracomment>remove completed (task, items)</extracomment>
        <translatorcomment>удалить выполнено (задача, элементы)</translatorcomment>
        <translation>&amp;Удаление завершено</translation>
    </message>
    <message>
        <source>Remove Completed Items</source>
        <translation>Удаление выполненных элементов</translation>
    </message>
    <message>
        <source>Remove all completed items in the list.</source>
        <translation>Удалите все завершенные элементы из списка.</translation>
    </message>
    <message>
        <source>Clear List</source>
        <translation>Очистить список</translation>
    </message>
    <message>
        <source>Remove all items in the list.</source>
        <translation>Удалите все элементы из списка.</translation>
    </message>
    <message>
        <source>&amp;Retry</source>
        <translation>&amp;Повторить</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Повторить</translation>
    </message>
    <message>
        <source>Retry selected tasks.</source>
        <translation>Повторите выполнение выбранных заданий.</translation>
    </message>
    <message>
        <source>Retry &amp;All</source>
        <translation>Повторить &amp;Всё</translation>
    </message>
    <message>
        <source>Retry all tasks.</source>
        <translation>Повторите все задания.</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>About This Program</source>
        <translation>О данной программе</translation>
    </message>
    <message>
        <source>Change Output &amp;Filename</source>
        <translation>Изменить итоговые данные &amp;имя файла</translation>
    </message>
    <message>
        <source>Change the output filename of the selected item.</source>
        <translation>Измените итоговое имя файла выбранного элемента.</translation>
    </message>
    <message>
        <source>Change Output &amp;Directory</source>
        <translation>Изменить итоговые данные &amp;Каталог</translation>
    </message>
    <message>
        <source>Change the output directory of the selected items.</source>
        <translation>Измените итоговый каталог выбранных элементов.</translation>
    </message>
    <message>
        <source>Show Error &amp;Message</source>
        <translation>Показать ошибку &amp;Сообщение</translation>
    </message>
    <message>
        <source>Check For &amp;Updates</source>
        <translation>Проверить наличие &amp;Обновлений</translation>
    </message>
    <message>
        <source>Cut</source>
        <extracomment>Cut video file (select a time range to conert)</extracomment>
        <translation>Резать</translation>
    </message>
    <message>
        <source>All tasks have finished.</source>
        <translation>Все задания выполнены.</translation>
    </message>
    <message>
        <source>Nothing to convert.</source>
        <translation>Нет объектов для конвертирования.</translation>
    </message>
    <message>
        <source>Conversion is still in progress. Abort?</source>
        <translation>Конвертация все еще продолжается. Прервать?</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <extracomment>Shutdown the computer (completely poweroff)</extracomment>
        <translation>Выключение</translation>
    </message>
    <message>
        <source>Shutdown when all tasks are done.</source>
        <translation>Выключить, когда все задачи выполнены.</translation>
    </message>
    <message>
        <source>Suspend</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>Приостановить</translation>
    </message>
    <message>
        <source>Suspend when all tasks are done.</source>
        <translation>Приостановить работу, когда все задачи будут выполнены.</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>Спящий режим</translation>
    </message>
    <message>
        <source>Hibernate when all tasks are done.</source>
        <translation>Спящий режим, когда все задачи выполнены.</translation>
    </message>
    <message>
        <source>This program is going to check for updates online. Do you allow this program to use the Internet to check for updates?</source>
        <translation>Эта программа будет проверять наличие обновлений в интернете. Разрешаете ли вы этой программе использовать Интернет для проверки обновлений?</translation>
    </message>
    <message>
        <source>Failed to load preset file. The application will quit now.</source>
        <translation>Не удалось загрузить предустановленный файл. Теперь приложение будет закрыто.</translation>
    </message>
    <message>
        <source>Elapsed Time: %1 h %2 m %3 s</source>
        <translation>Затраченное время: %1 ч %2 м %3 с</translation>
    </message>
    <message>
        <source>MystiQ Media Converter</source>
        <translation>MystiQ медиаконвертер</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Помощь</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>Clear &amp;List</source>
        <translation>Очистка &amp;списка</translation>
    </message>
    <message>
        <source>About MystiQ</source>
        <translation>О программе MystiQ</translation>
    </message>
    <message>
        <source>Poweroff</source>
        <translation>Отключить</translation>
    </message>
    <message>
        <source>User Manual</source>
        <translation>Руководство пользователя</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>&amp;Report Error</source>
        <translation>&amp;Сообщение об ошибке</translation>
    </message>
    <message>
        <source>Report Error</source>
        <translation>Сообщение об ошибке</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Пожертвование</translation>
    </message>
    <message>
        <source>Conversion failed.</source>
        <translation>Конвертация на удалась.</translation>
    </message>
    <message>
        <source>Support MystiQ</source>
        <translation>Техническая поддержка MystiQ</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>MystiQ needs you</source>
        <translation>MystiQ нуждается в тебе</translation>
    </message>
    <message>
        <source>MystiQ is free software. However the development requires a lot of time and a lot of work. In order to keep developing MystiQ with new features we need your help. Please consider to support the MystiQ project by sending a donation. &lt;b&gt;Even the smallest amount will help a lot.&lt;/b&gt;</source>
        <translation>MystiQ это бесплатное программное обеспечение. Однако разработка требует много времени и большой работы. Чтобы продолжать развивать MystiQ с новыми функциями, нам нужна ваша помощь. Пожалуйста, подумайте о том, чтобы поддержать проект MystiQ, отправив пожертвование. &lt;b&gt; Даже самая маленькая сумма очень поможет. &lt;/b&gt;</translation>
    </message>
    <message>
        <source>Reporting bugs from MystiQ </source>
        <translation>Сообщения об ошибках в MystiQ </translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Your comment:</source>
        <translation>Ваш комментарий:</translation>
    </message>
    <message>
        <source>Report:</source>
        <translation>Отчет:</translation>
    </message>
    <message>
        <source>MystiQ is Converting %1/%2</source>
        <extracomment>Converting the %1-th file in %2 files. %2 is the number of files.</extracomment>
        <translation>MystiQ конвертирует %1/%2</translation>
    </message>
    <message>
        <source>MystiQ Video Converter</source>
        <translation>MystiQ видео конвертер</translation>
    </message>
    <message>
        <source>Conversion finished successfully.</source>
        <translation>Конвертация закончилась успешно.</translation>
    </message>
    <message>
        <source>Translate</source>
        <translation>Перевод</translation>
    </message>
    <message>
        <source>Translate Application</source>
        <translation>Перевести программу</translation>
    </message>
    <message>
        <source>Report Bugs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Email</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>We need your feedback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Github</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MystiQ Video Converter development team needs users who use the application to help detect errors. If you find an error and report it to our team, it will help speed up the correction process. Therefore, you can be part of our development team even if you are not a developer. To report an error, you can send us an email with the detailed description of it or you can enter Github and describe the issue (in this case you must have a GitHub Account).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gitter</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaConverter</name>
    <message>
        <source> FFmpeg or FFprobe %1 have not been found in the system. Please consider installing them before running MystiQ</source>
        <extracomment>%1 is a computer program</extracomment>
        <translatorcomment>%1 - компьютерная программа</translatorcomment>
        <translation> FFmpeg или FFprobe %1 не найдены в системе. Пожалуйста, рассмотрите возможность их установки перед запуском MystiQ</translation>
    </message>
</context>
<context>
    <name>MediaPlayerWidget</name>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Главные</translation>
    </message>
    <message>
        <source>Check for updates on program startup</source>
        <translation>Проверьте наличие обновлений при запуске программы</translation>
    </message>
    <message>
        <source>Automatically start conversion after adding files to the list.</source>
        <translation>Автоматическое начало конвертации после добавления файлов в список.</translation>
    </message>
    <message>
        <source>Start conversion automatically</source>
        <translation>Автоматический запуск конвертации</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Number of threads to use in conversion</source>
        <translation>Количество потоков при конвертировании</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Hide output formats that are not available in the current ffmpeg installation. It is recommended to turn this option on unless you are sure that MystiQ has failed to detect available formats. (requires restarting MystiQ to take effect)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt; &lt;head/&gt; &lt;body&gt; &lt;p&gt; Скрыть итоговые форматы, которые недоступны в текущей установке ffmpeg. Рекомендуется включить эту опцию, если вы не уверены, что MystiQ не удалось обнаружить доступные форматы. (требуется перезапуск MystiQ для вступления в силу) &lt;/p&gt; &lt;/body&gt; &lt;/html&gt;</translation>
    </message>
    <message>
        <source>Hide unavailable formats (requires restarting)</source>
        <translation>Скрыть недоступные форматы (требуется перезапуск)</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Инструменты</translation>
    </message>
    <message>
        <source>You have to restart MystiQ for the changes to take effect.</source>
        <translation>Вы должны перезапустить MystiQ, чтобы изменения вступили в силу.</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Наименование</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Команда</translation>
    </message>
</context>
<context>
    <name>PoweroffDialog</name>
    <message>
        <source>MystiQ</source>
        <translation>MystiQ</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Shutdown immediately</source>
        <extracomment>Shutdown the computer</extracomment>
        <translation>Немедленное выключение</translation>
    </message>
    <message>
        <source>Suspend immediately</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>Немедленно приостановить</translation>
    </message>
    <message>
        <source>Hibernate immediately</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>Немедленно отправить в сон</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <extracomment>Shutdown the computer</extracomment>
        <translation>Выключение</translation>
    </message>
    <message>
        <source>Suspend</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>Приостановить</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>Сон</translation>
    </message>
    <message>
        <source>Operation Failed: %1</source>
        <translation>Ошибка операции: %1</translation>
    </message>
    <message>
        <source>Shutting down in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>Завершение работы в &lt;b&gt; %1 &lt;/b&gt; сек</translation>
    </message>
    <message>
        <source>Suspending in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>Приостановка в &lt;b&gt; %1 &lt;/b&gt;</translation>
    </message>
    <message>
        <source>Hibernating in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>Сон в &lt;b&gt; %1 &lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>PreviewDialog</name>
    <message>
        <source>Play Selected Range</source>
        <translation>Воспроизведение выбранного диапазона</translation>
    </message>
    <message>
        <source>Begin</source>
        <extracomment>noun, the beginning of the video</extracomment>
        <translation>Начало</translation>
    </message>
    <message>
        <source>End</source>
        <extracomment>noun, the end of the video</extracomment>
        <translation>Конец</translation>
    </message>
    <message>
        <source>Play %1~%2</source>
        <extracomment>play the video from time %1 to time %2. %1 and %2 are time in hh:mm:ss format.</extracomment>
        <translation>Пуск %1~%2</translation>
    </message>
    <message>
        <source>Video Preview</source>
        <translation>Предпросмотр видео</translation>
    </message>
</context>
<context>
    <name>TimeRangeEdit</name>
    <message>
        <source>From Begin</source>
        <translation>К началу</translation>
    </message>
    <message>
        <source>To End</source>
        <translation>К концу</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Show &amp;Release Notes</source>
        <translation>Отобразить &amp;Примечание к выпуску</translation>
    </message>
    <message>
        <source>Check for updates on program startup</source>
        <translation>Проверьте наличие обновлений при запуске программы</translation>
    </message>
    <message>
        <source>Downloading update information...</source>
        <translation>Загрузка информации об обновлении...</translation>
    </message>
    <message>
        <source>Cannot connect to server.</source>
        <translation>Не удается подключиться к серверу.</translation>
    </message>
    <message>
        <source>Failed to parse the received data.</source>
        <translation>Не удалось проанализировать полученные данные.</translation>
    </message>
    <message>
        <source>You are already using the latest version of MystiQ.</source>
        <translation>Вы уже используете последнюю версию MystiQ.</translation>
    </message>
    <message>
        <source>An unknown error has occurred.</source>
        <translation>Произошла неизвестная ошибка.</translation>
    </message>
    <message>
        <source>A new version of MystiQ has been released!</source>
        <translation>Вышла новая версия MystiQ!</translation>
    </message>
    <message>
        <source>Version &lt;b&gt;%1&lt;/b&gt; is available at %2.</source>
        <extracomment>%1 is version number, %2 is the project homepage</extracomment>
        <translation>Версия &lt;b&gt; %1 &lt;/b&gt; доступна в %2.</translation>
    </message>
    <message>
        <source>You can download this version using the link:</source>
        <translation>Вы можете скачать эту версию по ссылке:</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Проверить обновление</translation>
    </message>
    <message>
        <source>The current version you are using is newer than the release channel version.&lt;br&gt;Therefore, you are using the development channel.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
